==> ctxR_1.0.0.tar.gz: ctxR/tests/testthat/chemical/chemical/file/mrv/search/by-dtxsid.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/file/mrv/search/by-dtxsid/", 
    status_code = 404L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Tue, 21 May 2024 17:14:05 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "c3748702-c59e-4c6d-5f64-173b699ab4ca", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 d7b509440ac55e6d7b3c4c7ad48b08f2.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAH50-C2", `x-amz-cf-id` = "_k_CMMW0vSkJFYLu2rOiiBeMxOWrajzirdQ7QPQOFFcYKzgnsdLT9Q=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Tue, 21 May 2024 17:14:05 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "c3748702-c59e-4c6d-5f64-173b699ab4ca", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 d7b509440ac55e6d7b3c4c7ad48b08f2.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAH50-C2", `x-amz-cf-id` = "_k_CMMW0vSkJFYLu2rOiiBeMxOWrajzirdQ7QPQOFFcYKzgnsdLT9Q=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 0x74, 0x20, 0x46, 0x6f, 
    0x75, 0x6e, 0x64, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x73, 
    0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x34, 
    0x30, 0x34, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 0x65, 0x74, 
    0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 
    0x20, 0x73, 0x74, 0x61, 0x74, 0x69, 0x63, 0x20, 0x72, 0x65, 
    0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x20, 0x63, 0x68, 0x65, 
    0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x66, 0x69, 0x6c, 0x65, 
    0x2f, 0x6d, 0x72, 0x76, 0x2f, 0x73, 0x65, 0x61, 0x72, 0x63, 
    0x68, 0x2f, 0x62, 0x79, 0x2d, 0x64, 0x74, 0x78, 0x73, 0x69, 
    0x64, 0x2e, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 
    0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 
    0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 
    0x2f, 0x66, 0x69, 0x6c, 0x65, 0x2f, 0x6d, 0x72, 0x76, 0x2f, 
    0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 
    0x64, 0x74, 0x78, 0x73, 0x69, 0x64, 0x2f, 0x22, 0x0a, 0x7d
    )), date = structure(1716311645, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.5e-05, 
    connect = 0, pretransfer = 0.000168, starttransfer = 0.139916, 
    total = 0.139943)), class = "response")

==> ctxR_1.1.2.tar.gz: ctxR/tests/testthat/chemical/chemical/file/mrv/search/by-dtxsid.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/file/mrv/search/by-dtxsid/", 
    status_code = 404L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Fri, 08 Nov 2024 15:47:12 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "2f3c6ee4-79aa-4530-757a-52d72bbac97e", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 58f689028f521999dd25fa234ad8a3f4.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "FnQhGgtJzBpxx5z9kXrSkmM5xDgmAcL5yvVBJ3aEJklpIk9AaiSPVg=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Fri, 08 Nov 2024 15:47:12 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "2f3c6ee4-79aa-4530-757a-52d72bbac97e", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 58f689028f521999dd25fa234ad8a3f4.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "FnQhGgtJzBpxx5z9kXrSkmM5xDgmAcL5yvVBJ3aEJklpIk9AaiSPVg=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 0x74, 0x20, 0x46, 0x6f, 
    0x75, 0x6e, 0x64, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x73, 
    0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x34, 
    0x30, 0x34, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 0x65, 0x74, 
    0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x4e, 0x6f, 
    0x20, 0x73, 0x74, 0x61, 0x74, 0x69, 0x63, 0x20, 0x72, 0x65, 
    0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x20, 0x63, 0x68, 0x65, 
    0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x66, 0x69, 0x6c, 0x65, 
    0x2f, 0x6d, 0x72, 0x76, 0x2f, 0x73, 0x65, 0x61, 0x72, 0x63, 
    0x68, 0x2f, 0x62, 0x79, 0x2d, 0x64, 0x74, 0x78, 0x73, 0x69, 
    0x64, 0x2e, 0x22, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 
    0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 
    0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 
    0x2f, 0x66, 0x69, 0x6c, 0x65, 0x2f, 0x6d, 0x72, 0x76, 0x2f, 
    0x73, 0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 
    0x64, 0x74, 0x78, 0x73, 0x69, 0x64, 0x2f, 0x22, 0x0a, 0x7d
    )), date = structure(1731080832, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.5e-05, 
    connect = 0, pretransfer = 0.000131, starttransfer = 0.105681, 
    total = 0.105712)), class = "response")
